aboutsummaryrefslogtreecommitdiff
path: root/lib/csapi/typing.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/csapi/typing.h')
-rw-r--r--lib/csapi/typing.h56
1 files changed, 29 insertions, 27 deletions
diff --git a/lib/csapi/typing.h b/lib/csapi/typing.h
index c6201440..234e91b0 100644
--- a/lib/csapi/typing.h
+++ b/lib/csapi/typing.h
@@ -6,32 +6,34 @@
#include "jobs/basejob.h"
-#include "converters.h"
+namespace Quotient {
-namespace QMatrixClient
-{
- // Operations
+/*! \brief Informs the server that the user has started or stopped typing.
+ *
+ * This tells the server that the user is typing for the next N
+ * milliseconds where N is the value specified in the `timeout` key.
+ * Alternatively, if `typing` is `false`, it tells the server that the
+ * user has stopped typing.
+ */
+class QUOTIENT_API SetTypingJob : public BaseJob {
+public:
+ /*! \brief Informs the server that the user has started or stopped typing.
+ *
+ * \param userId
+ * The user who has started to type.
+ *
+ * \param roomId
+ * The room in which the user is typing.
+ *
+ * \param typing
+ * Whether the user is typing or not. If `false`, the `timeout`
+ * key can be omitted.
+ *
+ * \param timeout
+ * The length of time in milliseconds to mark this user as typing.
+ */
+ explicit SetTypingJob(const QString& userId, const QString& roomId,
+ bool typing, Omittable<int> timeout = none);
+};
- /// Informs the server that the user has started or stopped typing.
- ///
- /// This tells the server that the user is typing for the next N
- /// milliseconds where N is the value specified in the ``timeout`` key.
- /// Alternatively, if ``typing`` is ``false``, it tells the server that the
- /// user has stopped typing.
- class SetTypingJob : public BaseJob
- {
- public:
- /*! Informs the server that the user has started or stopped typing.
- * \param userId
- * The user who has started to type.
- * \param roomId
- * The room in which the user is typing.
- * \param typing
- * Whether the user is typing or not. If ``false``, the ``timeout``
- * key can be omitted.
- * \param timeout
- * The length of time in milliseconds to mark this user as typing.
- */
- explicit SetTypingJob(const QString& userId, const QString& roomId, bool typing, Omittable<int> timeout = none);
- };
-} // namespace QMatrixClient
+} // namespace Quotient